cmd

package
v1.8.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 12, 2026 License: Apache-2.0 Imports: 9 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var Version string = ""

Version is injected by the build.

Functions

func Execute

func Execute()

Execute is called by main.main() and executes the gnomon command.

Types

type HhMm

type HhMm string

HhMm is a string that represents a 24 hour clock time as hours and minutes in HH:MM format.

func (*HhMm) Set

func (hhmm *HhMm) Set(s string) error

Set sets a clock time and validates that the string argument is in the expected 24 hour clock format.

func (*HhMm) String

func (hhmm *HhMm) String() string

func (*HhMm) Type

func (hhmm *HhMm) Type() string

Type returns a string showing how a CLI should display the type.

func (*HhMm) Until

func (hhmm *HhMm) Until() (time.Duration, error)

Until returns the time.Duration until the specified clock time.

type SoC added in v0.3.0

type SoC int

SoC represent a battery's state of charge

func (*SoC) Int added in v0.3.0

func (soc *SoC) Int() int

Int converts a SoC to an int.

func (*SoC) Set added in v0.3.0

func (soc *SoC) Set(s string) error

Set sets a battery state of charge.

func (*SoC) String added in v0.3.0

func (soc *SoC) String() string

func (*SoC) Type added in v0.3.0

func (soc *SoC) Type() string

Type returns "SoC" as the type.

Jump to