Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var Version string = ""
Version is injected by the build.
Functions ¶
Types ¶
type HhMm ¶
type HhMm string
HhMm is a string that represents a 24 hour clock time as hours and minutes in HH:MM format.
func (*HhMm) Set ¶
Set sets a clock time and validates that the string argument is in the expected 24 hour clock format.
Click to show internal directories.
Click to hide internal directories.