Documentation
¶
Overview ¶
Package handlers includes functions that respond to changes reported by the inverter and can update the inverter's settings.
Index ¶
- func CtCoilHandler(ctx context.Context, wg *sync.WaitGroup, ch chan api.State)
- func DisplayHandler(ctx context.Context, ch chan api.State)
- func Fanout(chans ...chan api.State) chan api.State
- func ManageInverter(logfile string, delay time.Duration, runTime time.Duration, configFile string, ...) error
- func SocHandler(ctx context.Context, wg *sync.WaitGroup, minSoc int, ch chan api.State)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CtCoilHandler ¶
CtCoilHandler enables or disables power flowing from the inverter to non-essential circuits depending on the battery's SoC and the input power.
func DisplayHandler ¶
DisplayHandler displays the state of the inverter whenever it changes.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.